==> ask-sdk-model-0.2.tar.gz: ask-sdk-model-0.2/ask_sdk_model/interfaces/amazonpay/model/v1/destination.py <==
# coding: utf-8

#
# Copyright 2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional
    from datetime import datetime


class Destination(object):
    """
    The default shipping address of the buyer. Returned if needAmazonShippingAddress is set to true.


    :param name: The name or business name
    :type name: (optional) str
    :param company_name: The company name
    :type company_name: (optional) str
    :param address_line1: The first line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
    :type address_line1: (optional) str
    :param address_line2: The second line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
    :type address_line2: (optional) str
    :param address_line3: The third line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
    :type address_line3: (optional) str
    :param city: The city
    :type city: (optional) str
    :param district_or_county: The district or County
    :type district_or_county: (optional) str
    :param state_or_region: The state or region. This element is free text and can be either a 2-character code, fully spelled out, or abbreviated. Required. Note :- This response element is returned only in the U.S.
    :type state_or_region: (optional) str
    :param postal_code: The postal code.
    :type postal_code: (optional) str
    :param country_code: The country code, in ISO 3166 format
    :type country_code: (optional) str
    :param phone: The phone number
    :type phone: (optional) str

    """
    deserialized_types = {
        'name': 'str',
        'company_name': 'str',
        'address_line1': 'str',
        'address_line2': 'str',
        'address_line3': 'str',
        'city': 'str',
        'district_or_county': 'str',
        'state_or_region': 'str',
        'postal_code': 'str',
        'country_code': 'str',
        'phone': 'str'
    }

    attribute_map = {
        'name': 'name',
        'company_name': 'companyName',
        'address_line1': 'addressLine1',
        'address_line2': 'addressLine2',
        'address_line3': 'addressLine3',
        'city': 'city',
        'district_or_county': 'districtOrCounty',
        'state_or_region': 'stateOrRegion',
        'postal_code': 'postalCode',
        'country_code': 'countryCode',
        'phone': 'phone'
    }

    def __init__(self, name=None, company_name=None, address_line1=None, address_line2=None, address_line3=None, city=None, district_or_county=None, state_or_region=None, postal_code=None, country_code=None, phone=None):
        # type: (Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str]) -> None
        """The default shipping address of the buyer. Returned if needAmazonShippingAddress is set to true.

        :param name: The name or business name
        :type name: (optional) str
        :param company_name: The company name
        :type company_name: (optional) str
        :param address_line1: The first line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
        :type address_line1: (optional) str
        :param address_line2: The second line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
        :type address_line2: (optional) str
        :param address_line3: The third line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
        :type address_line3: (optional) str
        :param city: The city
        :type city: (optional) str
        :param district_or_county: The district or County
        :type district_or_county: (optional) str
        :param state_or_region: The state or region. This element is free text and can be either a 2-character code, fully spelled out, or abbreviated. Required. Note :- This response element is returned only in the U.S.
        :type state_or_region: (optional) str
        :param postal_code: The postal code.
        :type postal_code: (optional) str
        :param country_code: The country code, in ISO 3166 format
        :type country_code: (optional) str
        :param phone: The phone number
        :type phone: (optional) str
        """
        self.__discriminator_value = None

        self.name = name
        self.company_name = company_name
        self.address_line1 = address_line1
        self.address_line2 = address_line2
        self.address_line3 = address_line3
        self.city = city
        self.district_or_county = district_or_county
        self.state_or_region = state_or_region
        self.postal_code = postal_code
        self.country_code = country_code
        self.phone = phone

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, Destination):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other

==> ask-sdk-model-1.22.0.tar.gz: ask-sdk-model-1.22.0/ask_sdk_model/interfaces/amazonpay/model/v1/destination.py <==
# coding: utf-8

#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file
# except in compliance with the License. A copy of the License is located at
#
# http://aws.amazon.com/apache2.0/
#
# or in the "license" file accompanying this file. This file is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
# the specific language governing permissions and limitations under the License.
#

import pprint
import re  # noqa: F401
import six
import typing
from enum import Enum


if typing.TYPE_CHECKING:
    from typing import Dict, List, Optional, Union
    from datetime import datetime


class Destination(object):
    """
    Destination object containing the details of an Address.


    :param name: The name or business name
    :type name: (optional) str
    :param company_name: The company name
    :type company_name: (optional) str
    :param address_line1: The first line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
    :type address_line1: (optional) str
    :param address_line2: The second line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
    :type address_line2: (optional) str
    :param address_line3: The third line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
    :type address_line3: (optional) str
    :param city: The city
    :type city: (optional) str
    :param district_or_county: The district or County
    :type district_or_county: (optional) str
    :param state_or_region: The state or region. This element is free text and can be either a 2-character code, fully spelled out, or abbreviated. Required. Note :- This response element is returned only in the U.S.
    :type state_or_region: (optional) str
    :param postal_code: The postal code.
    :type postal_code: (optional) str
    :param country_code: The country code, in ISO 3166 format
    :type country_code: (optional) str
    :param phone: The phone number
    :type phone: (optional) str

    """
    deserialized_types = {
        'name': 'str',
        'company_name': 'str',
        'address_line1': 'str',
        'address_line2': 'str',
        'address_line3': 'str',
        'city': 'str',
        'district_or_county': 'str',
        'state_or_region': 'str',
        'postal_code': 'str',
        'country_code': 'str',
        'phone': 'str'
    }  # type: Dict

    attribute_map = {
        'name': 'name',
        'company_name': 'companyName',
        'address_line1': 'addressLine1',
        'address_line2': 'addressLine2',
        'address_line3': 'addressLine3',
        'city': 'city',
        'district_or_county': 'districtOrCounty',
        'state_or_region': 'stateOrRegion',
        'postal_code': 'postalCode',
        'country_code': 'countryCode',
        'phone': 'phone'
    }  # type: Dict
    supports_multiple_types = False

    def __init__(self, name=None, company_name=None, address_line1=None, address_line2=None, address_line3=None, city=None, district_or_county=None, state_or_region=None, postal_code=None, country_code=None, phone=None):
        # type: (Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str], Optional[str]) -> None
        """Destination object containing the details of an Address.

        :param name: The name or business name
        :type name: (optional) str
        :param company_name: The company name
        :type company_name: (optional) str
        :param address_line1: The first line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
        :type address_line1: (optional) str
        :param address_line2: The second line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
        :type address_line2: (optional) str
        :param address_line3: The third line of the address. At least one AddressLine (AddressLine1, AddressLine2, or AddressLine3) is required.
        :type address_line3: (optional) str
        :param city: The city
        :type city: (optional) str
        :param district_or_county: The district or County
        :type district_or_county: (optional) str
        :param state_or_region: The state or region. This element is free text and can be either a 2-character code, fully spelled out, or abbreviated. Required. Note :- This response element is returned only in the U.S.
        :type state_or_region: (optional) str
        :param postal_code: The postal code.
        :type postal_code: (optional) str
        :param country_code: The country code, in ISO 3166 format
        :type country_code: (optional) str
        :param phone: The phone number
        :type phone: (optional) str
        """
        self.__discriminator_value = None  # type: str

        self.name = name
        self.company_name = company_name
        self.address_line1 = address_line1
        self.address_line2 = address_line2
        self.address_line3 = address_line3
        self.city = city
        self.district_or_county = district_or_county
        self.state_or_region = state_or_region
        self.postal_code = postal_code
        self.country_code = country_code
        self.phone = phone

    def to_dict(self):
        # type: () -> Dict[str, object]
        """Returns the model properties as a dict"""
        result = {}  # type: Dict

        for attr, _ in six.iteritems(self.deserialized_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else
                    x.value if isinstance(x, Enum) else x,
                    value
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else
                    (item[0], item[1].value)
                    if isinstance(item[1], Enum) else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        # type: () -> str
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        # type: () -> str
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are equal"""
        if not isinstance(other, Destination):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        # type: (object) -> bool
        """Returns true if both objects are not equal"""
        return not self == other
